ExecutionPath

Struct ExecutionPath 

pub struct ExecutionPath {
    pub symbols: Vec<SymbolInfo>,
    pub length: usize,
}
Execution path in the call graph

Represents a single path through the call graph from a starting symbol to an ending symbol, with metadata about the path.

Fields

symbols: Vec<SymbolInfo>

Symbols along the path in order from start to end

length: usize

Number of symbols in the path