get_function_hash

Function get_function_hash 

pub fn get_function_hash(conn: &Connection, function_id: i64) -> Option<String>
Get the stored hash for a function

Arguments

  • conn - Database connection
  • function_id - ID of the function

Returns

  • Some(hash) - The stored BLAKE3 hash if function exists
  • None - Function not found or no hash stored

Note

Magellan’s cfg_blocks table doesn’t store function_hash, so this function always returns None when using Magellan’s schema. The hash functionality is only available when using Mirage’s legacy schema.